"use strict";
/** -------------------------------------------------------------------------------------
 * 	Modules
 * 	-------------------------------------------------------------------------------------
 */
var winston = require('winston');

/**
 * 	-------------------------------------------------------------------------------------	
 * 
 * 	Custom winston logger module
 * 
 * 	-------------------------------------------------------------------------------------
 */

var levels = { fatal: 0, error: 1, warn: 2, success: 3, info: 4, debug: 5 };

var logger = new winston.Logger();
logger.setLevels(levels);
logger.add(winston.transports.Console);
logger.transports.console.colorize = true;

winston.config.addColors({ fatal: 'magenta', error: 'red', warn: 'yellow', success: "green", info: 'grey', debug: 'cyan' });

var log = function (module, level, uuid, message, metadata) {
  	logger.log(level, JSON.stringify({
	    timestamp: new Date(),
	    module: module,
	    uuid: uuid,
	    level: level,
	    message: message,
	    metadata: metadata
  	}));
};

var CLogger = {

	add: function (transport, options) {
    	logger.add(transport, options);
  	},

  	remove: function (transport) {
    	logger.remove(transport);
  	},

  	getLogger: function (options) {
   	 	return {
	  		fatal: function (uuid, message, metadata) {
	    		log(options.module, 'fatal', uuid, message, metadata);
	  		},
	  		error: function (uuid, message, metadata) {
	    		log(options.module, 'error', uuid, message, metadata);
	 		},
	  		warn: function (uuid, message, metadata) {
	    		log(options.module, 'warn', uuid, message, metadata);
	  		},
	  		info: function (uuid, message, metadata) {
	    		log(options.module, 'info', uuid, message, metadata);
	  		},
	  		success: function (uuid, message, metadata) {
	    		log(options.module, 'success', uuid, message, metadata);
	  		},	  			  		
	  		debug: function (uuid, message, metadata) {
	    		log(options.module, 'debug', uuid, message, metadata);
	  		}
    	};
  	}	
};

module.exports = CLogger;